/*
 * SCIM Bridge
 *
 * Copyright (c) 2006 Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.*
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU Lesser General Public License for more details.*
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 * @file
 * @author Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 * @brief This is the header for the protected interfaces of the clients.
 */

#ifndef SCIMBRIDGECLIENTPROTECTED_H_
#define SCIMBRIDGECLIENTPROTECTED_H_

#ifdef __cplusplus
extern "C"
{
#endif

    /**
     * The connection is established with the agent.
     */
    void scim_bridge_client_messenger_opened ();

    /**
     * The connection with the agent is closed.
     */
    void scim_bridge_client_messenger_closed ();

#ifdef __cplusplus
}
#endif
#endif                                            /*SCIMBRIDGECLIENTPROTECTED_H_*/
